Crate type_dispatch_macros

Crate type_dispatch_macros 

Macros for dispatching based on generic types.

Macros

dispatch_const
Dispatches a constant based on a given generic type.
dispatch_fn
Dispatches a function body based on a given generic type.
dispatch_impl
A function-like variant of impl_dispatch.
dispatch_type
Dispatches a constant based on a given generic type.

Attribute Macros

impl_dispatch
Dispatches a trait implementation to a specified set of generic types.