Macros for dispatching based on generic types.
Macros
- dispatch_
const - Dispatches a constant based on a given generic type.
- dispatch_
fn - Dispatches a function body based on a given generic type.
- dispatch_
impl - A function-like variant of
impl_dispatch. - dispatch_
type - Dispatches a constant based on a given generic type.
Attribute Macros
- impl_
dispatch - Dispatches a trait implementation to a specified set of generic types.